



if not defined PYTHONNOUSERSITE exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if %PYTHONNOUSERSITE% NEQ 1 exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not defined R_LIBS_USER exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not %R_LIBS_USER%=="-" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
